==> claromentis-framework-8.13.65-b8aa1bfb.zip: console/src/Style/MultiplexedStyle.php <==
<?php
namespace Claromentis\Console\Style;

$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array();
use Claromentis\Console\Output\MultiplexedOutput;
use Symfony\Component\Console\Formatter\OutputFormatterInterface;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;








class MultiplexedStyle extends SymfonyStyle
{
    
    
    
    
    protected $input;
    
    
    
    
    protected $output;
    
    
    
    
    
    
    protected $styles = [];
    
    
    
    
    
    
    
    
    protected $style;
    
    
    
    
    
    
    
    public function __construct(InputInterface $_db34e0d240ded70491dbd8f19596a6cd, MultiplexedOutput $_1078c0d5e533406287785a6c20cf7587)
    {
        parent::__construct($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587);
        $this->input = $_db34e0d240ded70491dbd8f19596a6cd;
        $this->output = $_1078c0d5e533406287785a6c20cf7587;
        $this->styles = [];
        $this->style = new SymfonyStyle($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587);
        $_3afbfd6216bfbb1e35b97511f18c8397 = $_1078c0d5e533406287785a6c20cf7587->getInterfaces();
        foreach ($_3afbfd6216bfbb1e35b97511f18c8397 as $_5b08afc6598666e83143bd42ce733d9c) {
            $this->styles[] = new SymfonyStyle($_db34e0d240ded70491dbd8f19596a6cd, $_5b08afc6598666e83143bd42ce733d9c);
        }
    }
    
    
    
    
    
    
    public function getStyles()
    {
        return $this->styles;
    }
    
    
    
    
    
    
    public function each(callable $_5c51b0e4b7267b43adabf8015a8e1cf8)
    {
        foreach ($this->getStyles() as $_ec5506f22f4380697838f5559d75d370) {
            $_5c51b0e4b7267b43adabf8015a8e1cf8($_ec5506f22f4380697838f5559d75d370);
        }
    }
    
    
    
    
    
    
    
    
    public function write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea = false, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    
    public function writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    public function setVerbosity($_8571ac32155d45081f21fab1bc366aff)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->setVerbosity($_8571ac32155d45081f21fab1bc366aff);
        }
    }
    
    
    
    
    
    
    public function getVerbosity()
    {
        return $this->output->getVerbosity();
    }
    
    
    
    
    
    
    public function isQuiet()
    {
        return $this->output->isQuiet();
    }
    
    
    
    
    
    
    public function isVerbose()
    {
        return $this->output->isVerbose();
    }
    
    
    
    
    
    
    public function isVeryVerbose()
    {
        return $this->output->isVeryVerbose();
    }
    
    
    
    
    
    
    public function isDebug()
    {
        return $this->output->isDebug();
    }
    
    
    
    
    
    
    public function setDecorated($_4de82f87bac18df795ec4161918650aa)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->setDecorated($_4de82f87bac18df795ec4161918650aa);
        }
    }
    
    
    
    
    
    
    public function isDecorated()
    {
        return $this->output->isDecorated();
    }
    public function setFormatter(OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3)
    {
        $this->output->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        }
    }
    
    
    
    
    
    
    public function getFormatter()
    {
        return $this->output->getFormatter();
    }
    
    
    
    
    
    
    public function title($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->title($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function section($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->section($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function listing(array $_cbc16e6843fb081a429049d81663ce2b)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->listing($_cbc16e6843fb081a429049d81663ce2b);
        }
    }
    
    
    
    
    
    
    public function text($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->text($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function success($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->success($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function error($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->error($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function warning($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->warning($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function note($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->note($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function caution($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->caution($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    
    public function table(array $_3e258c4e6163007d8094c39647602e7a, array $_a0006f2e6058ce959e86bebdcded2da8)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->table($_3e258c4e6163007d8094c39647602e7a, $_a0006f2e6058ce959e86bebdcded2da8);
        }
    }
    
    
    
    
    
    
    
    
    
    
    public function ask($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1 = null, $_24c8d051c033d19c2c97cdc3d7098b1b = null)
    {
        return $this->style->ask($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1, $_24c8d051c033d19c2c97cdc3d7098b1b);
    }
    
    
    
    
    
    
    
    
    
    public function askHidden($_4fd57af43f8d56fd8d852252979688e8, $_24c8d051c033d19c2c97cdc3d7098b1b = null)
    {
        return $this->style->askHidden($_4fd57af43f8d56fd8d852252979688e8, $_24c8d051c033d19c2c97cdc3d7098b1b);
    }
    
    
    
    
    
    
    
    
    
    public function confirm($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1 = true)
    {
        return $this->style->confirm($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1);
    }
    
    
    
    
    
    
    
    
    
    
    public function choice($_4fd57af43f8d56fd8d852252979688e8, array $_5485223e1733e5892066ebf5f2123657, $_8dc0592537dc5fb48873bb782fa6feb1 = null)
    {
        return $this->style->choice($_4fd57af43f8d56fd8d852252979688e8, $_5485223e1733e5892066ebf5f2123657, $_8dc0592537dc5fb48873bb782fa6feb1);
    }
    
    
    
    
    
    
    public function newLine($_f53d35a1a1e233d98d9ce73d92ab3bb1 = 1)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->newLine($_f53d35a1a1e233d98d9ce73d92ab3bb1);
        }
    }
    
    
    
    
    
    
    public function progressStart($_c482f647d2101bbd08513ba0acc302aa = 0)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->progressStart($_c482f647d2101bbd08513ba0acc302aa);
        }
    }
    
    
    
    
    
    
    public function progressAdvance($_92550e0660b12d9578f7cbb9f7bd333a = 1)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->progressAdvance($_92550e0660b12d9578f7cbb9f7bd333a);
        }
    }
    
    
    
    
    public function progressFinish()
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->progressFinish();
        }
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: console/src/Style/MultiplexedStyle.php <==
<?php
namespace Claromentis\Console\Style;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array();
use Claromentis\Console\Output\MultiplexedOutput;
use Symfony\Component\Console\Formatter\OutputFormatterInterface;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;








class MultiplexedStyle extends SymfonyStyle
{
    
    
    
    
    protected $input;
    
    
    
    
    protected $output;
    
    
    
    
    
    
    protected $styles = [];
    
    
    
    
    
    
    
    
    protected $style;
    
    
    
    
    
    
    
    public function __construct(InputInterface $_db34e0d240ded70491dbd8f19596a6cd, MultiplexedOutput $_1078c0d5e533406287785a6c20cf7587)
    {
        parent::__construct($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587);
        $this->input = $_db34e0d240ded70491dbd8f19596a6cd;
        $this->output = $_1078c0d5e533406287785a6c20cf7587;
        $this->styles = [];
        $this->style = new SymfonyStyle($_db34e0d240ded70491dbd8f19596a6cd, $_1078c0d5e533406287785a6c20cf7587);
        $_3afbfd6216bfbb1e35b97511f18c8397 = $_1078c0d5e533406287785a6c20cf7587->getInterfaces();
        foreach ($_3afbfd6216bfbb1e35b97511f18c8397 as $_5b08afc6598666e83143bd42ce733d9c) {
            $this->styles[] = new SymfonyStyle($_db34e0d240ded70491dbd8f19596a6cd, $_5b08afc6598666e83143bd42ce733d9c);
        }
    }
    
    
    
    
    
    
    public function getStyles()
    {
        return $this->styles;
    }
    
    
    
    
    
    
    public function each(callable $_5c51b0e4b7267b43adabf8015a8e1cf8)
    {
        foreach ($this->getStyles() as $_ec5506f22f4380697838f5559d75d370) {
            $_5c51b0e4b7267b43adabf8015a8e1cf8($_ec5506f22f4380697838f5559d75d370);
        }
    }
    
    
    
    
    
    
    
    
    public function write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea = false, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->write($_fab5a2188c706d282c3aea92f0ccbd01, $_b37ac8a628a4f0ebbe09819dd2a00dea, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    
    public function writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b = 0)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->writeln($_fab5a2188c706d282c3aea92f0ccbd01, $_61fbb5071d97b5eb5a2d82e386e63d7b);
        }
    }
    
    
    
    
    
    
    public function setVerbosity($_8571ac32155d45081f21fab1bc366aff)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->setVerbosity($_8571ac32155d45081f21fab1bc366aff);
        }
    }
    
    
    
    
    
    
    public function getVerbosity()
    {
        return $this->output->getVerbosity();
    }
    
    
    
    
    
    
    public function isQuiet()
    {
        return $this->output->isQuiet();
    }
    
    
    
    
    
    
    public function isVerbose()
    {
        return $this->output->isVerbose();
    }
    
    
    
    
    
    
    public function isVeryVerbose()
    {
        return $this->output->isVeryVerbose();
    }
    
    
    
    
    
    
    public function isDebug()
    {
        return $this->output->isDebug();
    }
    
    
    
    
    
    
    public function setDecorated($_4de82f87bac18df795ec4161918650aa)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->setDecorated($_4de82f87bac18df795ec4161918650aa);
        }
    }
    
    
    
    
    
    
    public function isDecorated()
    {
        return $this->output->isDecorated();
    }
    public function setFormatter(OutputFormatterInterface $_a83a2289b24ef3674668e88bc61b3ab3)
    {
        $this->output->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->setFormatter($_a83a2289b24ef3674668e88bc61b3ab3);
        }
    }
    
    
    
    
    
    
    public function getFormatter()
    {
        return $this->output->getFormatter();
    }
    
    
    
    
    
    
    public function title($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->title($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function section($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->section($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function listing(array $_cbc16e6843fb081a429049d81663ce2b)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->listing($_cbc16e6843fb081a429049d81663ce2b);
        }
    }
    
    
    
    
    
    
    public function text($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->text($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function success($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->success($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function error($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->error($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function warning($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->warning($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function note($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->note($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    public function caution($_e05e0022a2e5ad344b9c4a0d3f64e1a5)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->caution($_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        }
    }
    
    
    
    
    
    
    
    public function table(array $_3e258c4e6163007d8094c39647602e7a, array $_a0006f2e6058ce959e86bebdcded2da8)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->table($_3e258c4e6163007d8094c39647602e7a, $_a0006f2e6058ce959e86bebdcded2da8);
        }
    }
    
    
    
    
    
    
    
    
    
    
    public function ask($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1 = null, $_24c8d051c033d19c2c97cdc3d7098b1b = null)
    {
        return $this->style->ask($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1, $_24c8d051c033d19c2c97cdc3d7098b1b);
    }
    
    
    
    
    
    
    
    
    
    public function askHidden($_4fd57af43f8d56fd8d852252979688e8, $_24c8d051c033d19c2c97cdc3d7098b1b = null)
    {
        return $this->style->askHidden($_4fd57af43f8d56fd8d852252979688e8, $_24c8d051c033d19c2c97cdc3d7098b1b);
    }
    
    
    
    
    
    
    
    
    
    public function confirm($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1 = true)
    {
        return $this->style->confirm($_4fd57af43f8d56fd8d852252979688e8, $_8dc0592537dc5fb48873bb782fa6feb1);
    }
    
    
    
    
    
    
    
    
    
    
    public function choice($_4fd57af43f8d56fd8d852252979688e8, array $_5485223e1733e5892066ebf5f2123657, $_8dc0592537dc5fb48873bb782fa6feb1 = null)
    {
        return $this->style->choice($_4fd57af43f8d56fd8d852252979688e8, $_5485223e1733e5892066ebf5f2123657, $_8dc0592537dc5fb48873bb782fa6feb1);
    }
    
    
    
    
    
    
    public function newLine($_f53d35a1a1e233d98d9ce73d92ab3bb1 = 1)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->newLine($_f53d35a1a1e233d98d9ce73d92ab3bb1);
        }
    }
    
    
    
    
    
    
    public function progressStart($_c482f647d2101bbd08513ba0acc302aa = 0)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->progressStart($_c482f647d2101bbd08513ba0acc302aa);
        }
    }
    
    
    
    
    
    
    public function progressAdvance($_92550e0660b12d9578f7cbb9f7bd333a = 1)
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->progressAdvance($_92550e0660b12d9578f7cbb9f7bd333a);
        }
    }
    
    
    
    
    public function progressFinish()
    {
        foreach ($this->styles as $_ec5506f22f4380697838f5559d75d370) {
            $_ec5506f22f4380697838f5559d75d370->progressFinish();
        }
    }
}
